RoutingState class
Constructors
- RoutingState({required RoutingStatus status, RouteResult? route, String? destinationLabel, String? errorMessage, bool engineAvailable = false})
-
const
- RoutingState.idle({bool engineAvailable = false})
-
const
Properties
- destinationLabel → String?
-
final
- engineAvailable → bool
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRoute → bool
-
no setter
- isLoading → bool
-
no setter
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- route → RouteResult?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → RoutingStatus
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{RoutingStatus? status, Object? route = _noChange, Object? destinationLabel = _noChange, Object? errorMessage = _noChange, bool? engineAvailable}) → RoutingState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited